Documentation
¶
Index ¶
- type Config
- type Option
- type Popup
- type Progress
- func (p *Progress) OnEnter(i any) tea.Cmd
- func (p *Progress) OnExit() any
- func (p *Progress) Render() orvyn.Layout
- func (p *Progress) Reset()
- func (p *Progress) SetBarColor(color lipgloss.Color)
- func (p *Progress) SetCancelKeybind(key *key.Binding)
- func (p *Progress) Update(msg tea.Msg) tea.Cmd
- func (p *Progress) UpdateProgress(steps, maxSteps int)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Popup ¶
type Popup struct {
// contains filtered or unexported fields
}
type Progress ¶
type Progress struct {
// Interrupted flag will hold true if the progress was interrupted by the user.
Interrupted bool
// contains filtered or unexported fields
}
Progress is a dialog for quick implementation of a progress dialog.
func NewProgress ¶
NewProgress returns a new screen that represents a progress dialog. This screen needs to be used with orvyn.OpenDialog().
func (*Progress) Reset ¶
func (p *Progress) Reset()
Reset helps resetting the dialog to it's default state.
func (*Progress) SetBarColor ¶
SetBarColor helps changing the underlying progressBar color.
func (*Progress) SetCancelKeybind ¶
SetCancelKeybind helps defining or removing a cancel keybind. The given keybind must have the Help initialized. For example :
keybind := key.NewBinding(key.WithKeys("esc"), key.WithHelp("esc", "cancel")) p.dial.SetCancelKeybind(&keybind)
func (*Progress) UpdateProgress ¶
UpdateProgress should be used to update the underlying progressBar.
Click to show internal directories.
Click to hide internal directories.