Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MessageType ¶
type MessageType int
const ( ErrorMessage MessageType = iota SuccessMessage WarningMessage InformationMessage NeutralMessage )
type Widget ¶
type Widget struct {
orvyn.BaseWidget
// contains filtered or unexported fields
}
Widget is a status message that can hold different type of message. Each message type have it's own style based on theme Status TextStyleID.
func (*Widget) GetMinSize ¶
func (*Widget) GetPreferredSize ¶
func (*Widget) Reset ¶
func (w *Widget) Reset()
Reset helps resetting the widget to it's default state.
func (*Widget) SetMessage ¶
func (w *Widget) SetMessage(msg string, msgType MessageType)
SetMessage helps defining the message and the type of the message of the widget.
Click to show internal directories.
Click to hide internal directories.